==> warcar-1.0.0-20171226.024301-23-sources.jar: com/bxm/warcar/cache/impls/redis/JedisUpdater.java <==
package com.bxm.warcar.cache.impls.redis;

import com.bxm.warcar.cache.KeyGenerator;
import com.bxm.warcar.cache.Updater;
import com.bxm.warcar.cache.serialization.JSONSerialization;
import com.google.common.base.Preconditions;
import org.apache.commons.lang.StringUtils;
import redis.clients.jedis.Jedis;
import redis.clients.jedis.JedisPool;

import static com.bxm.warcar.cache.impls.redis.JedisFetcher.HASH_ALL_FIELD;

/**
 * @author allen
 * @date 2017-12-04
 */
public class JedisUpdater implements Updater {

    private final JedisPool jedisPool;
    private final JSONSerialization serialization;

    /**
     * 是否启用ALL_FIELD实现
     */
    private boolean enableAllField = true;
    private String allFieldName = HASH_ALL_FIELD;

    public JedisUpdater(JedisPool jedisPool) {
        this.jedisPool = jedisPool;
        this.serialization = new JSONSerialization();
    }

    @Override
    public void update(KeyGenerator keyGenerator, Object value, int expireTimeInSecond) {
        Preconditions.checkNotNull(keyGenerator);
        String key = keyGenerator.generateKey();
        if (StringUtils.isBlank(key)) {
            throw new NullPointerException("key");
        }
        if (null == value)
            throw new NullPointerException("value");

        Jedis jedis = null;
        try {
            jedis = jedisPool.getResource();

            jedis.set(key, this.serialization.serialize(value));
            if (expireTimeInSecond > 0)
                jedis.expire(key, expireTimeInSecond);
        }
        finally {
            if (null != jedis) {
                jedis.close();
            }
        }
    }

    @Override
    public void update(KeyGenerator keyGenerator, Object value) {
        this.update(keyGenerator, value, 0);
    }

    @Override
    public void remove(KeyGenerator keyGenerator) {
        Preconditions.checkNotNull(keyGenerator);
        String key = keyGenerator.generateKey();
        if (StringUtils.isBlank(key)) {
            throw new NullPointerException("key");
        }

        Jedis jedis = null;
        try {
            jedis = jedisPool.getResource();
            jedis.del(key);
        }
        finally {
            if (null != jedis) {
                jedis.close();
            }
        }
    }

    @Override
    public void hupdate(KeyGenerator keyGenerator, String field, Object value) {
        this.hupdate(keyGenerator, field, value, 0);
    }

    @Override
    public void hupdate(KeyGenerator keyGenerator, String field, Object value, int expireTimeInSecond) {
        Preconditions.checkNotNull(keyGenerator);
        String key = keyGenerator.generateKey();
        if (StringUtils.isBlank(key)) {
            throw new NullPointerException("key");
        }
        if (null == value)
            throw new NullPointerException("value");
        if (StringUtils.isBlank(field))
            throw new NullPointerException("field");

        Jedis jedis = null;
        try {
            jedis = jedisPool.getResource();

            jedis.hset(key, field, this.serialization.serialize(value));
            if (expireTimeInSecond > 0)
                jedis.expire(key, expireTimeInSecond);

            if (enableAllField) {
                jedis.hdel(key, allFieldName);
            }
        }
        finally {
            if (null != jedis) {
                jedis.close();
            }
        }
    }

    public boolean isEnableAllField() {
        return enableAllField;
    }

    public void setEnableAllField(boolean enableAllField) {
        this.enableAllField = enableAllField;
    }

    public String getAllFieldName() {
        return allFieldName;
    }

    public void setAllFieldName(String allFieldName) {
        this.allFieldName = allFieldName;
    }
}

==> warcar-1.0.2-20180312.140057-1-sources.jar: com/bxm/warcar/cache/impls/redis/JedisUpdater.java <==
package com.bxm.warcar.cache.impls.redis;

import com.bxm.warcar.cache.KeyGenerator;
import com.bxm.warcar.cache.Updater;
import com.bxm.warcar.cache.serialization.JSONSerialization;
import com.google.common.base.Preconditions;
import org.apache.commons.lang.StringUtils;
import redis.clients.jedis.Jedis;
import redis.clients.jedis.JedisPool;

import java.util.Map;

/**
 * @author allen
 * @date 2017-12-04
 */
public class JedisUpdater implements Updater {

    private final JedisPool jedisPool;
    private final JSONSerialization serialization;

    public JedisUpdater(JedisPool jedisPool) {
        this.jedisPool = jedisPool;
        this.serialization = new JSONSerialization();
    }

    @Override
    public Object getClientOriginal() {
        return jedisPool;
    }

    @Override
    public void update(KeyGenerator keyGenerator, Object value, int expireTimeInSecond) {
        Preconditions.checkNotNull(keyGenerator);
        String key = keyGenerator.generateKey();
        if (StringUtils.isBlank(key)) {
            throw new NullPointerException("key");
        }
        if (null == value) {
            throw new NullPointerException("value");
        }

        Jedis jedis = null;
        try {
            jedis = jedisPool.getResource();

            jedis.set(key, this.serialization.serialize(value));
            if (expireTimeInSecond > 0) {
                jedis.expire(key, expireTimeInSecond);
            }
        }
        finally {
            if (null != jedis) {
                jedis.close();
            }
        }
    }

    @Override
    public void update(KeyGenerator keyGenerator, Object value) {
        this.update(keyGenerator, value, 0);
    }

    @Override
    public void mupdate(KeyGenerator keyGenerator, Map<String, Object> values) {
    }

    @Override
    public void mupdate(KeyGenerator keyGenerator, Map<String, Object> values, int expireTimeInSecond) {
    }

    @Override
    public void remove(KeyGenerator keyGenerator) {
        Preconditions.checkNotNull(keyGenerator);
        String key = keyGenerator.generateKey();
        if (StringUtils.isBlank(key)) {
            throw new NullPointerException("key");
        }

        Jedis jedis = null;
        try {
            jedis = jedisPool.getResource();
            jedis.del(key);
        }
        finally {
            if (null != jedis) {
                jedis.close();
            }
        }
    }

    @Override
    public void hupdate(KeyGenerator keyGenerator, String field, Object value) {
        this.hupdate(keyGenerator, field, value, 0);
    }

    @Override
    public void hupdate(KeyGenerator keyGenerator, String field, Object value, int expireTimeInSecond) {
        Preconditions.checkNotNull(keyGenerator);
        String key = keyGenerator.generateKey();
        if (StringUtils.isBlank(key)) {
            throw new NullPointerException("key");
        }
        if (null == value)
            throw new NullPointerException("value");
        if (StringUtils.isBlank(field))
            throw new NullPointerException("field");

        Jedis jedis = null;
        try {
            jedis = jedisPool.getResource();

            jedis.hset(key, field, this.serialization.serialize(value));
            if (expireTimeInSecond > 0)
                jedis.expire(key, expireTimeInSecond);
        }
        finally {
            if (null != jedis) {
                jedis.close();
            }
        }
    }

    @Override
    public void hremove(KeyGenerator keyGenerator, String...field) {
        Preconditions.checkNotNull(keyGenerator);
        String key = keyGenerator.generateKey();
        if (StringUtils.isBlank(key)) {
            throw new NullPointerException("key");
        }

        Jedis jedis = null;
        try {
            jedis = jedisPool.getResource();

            jedis.hdel(key, field);
        }
        finally {
            if (null != jedis) {
                jedis.close();
            }
        }
    }
}
